summaryrefslogtreecommitdiff
path: root/src/modules/m_spy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_spy.cpp')
-rw-r--r--src/modules/m_spy.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_spy.cpp b/src/modules/m_spy.cpp
index 54d2983b0..75fe2b367 100644
--- a/src/modules/m_spy.cpp
+++ b/src/modules/m_spy.cpp
@@ -25,8 +25,8 @@ class ModuleSpy : public Module
virtual int OnUserList(User* user, Channel* Ptr, CUList* &nameslist)
{
- /* User is an oper and is NOT on the channel */
- if (IS_OPER(user) && !Ptr->HasUser(user))
+ /* User has priv and is NOT on the channel */
+ if (user->HasPrivPermission("channels/auspex") && !Ptr->HasUser(user))
return -1;
return 0;